<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>QApplication</name>
    <message>
        <source>MX Tweak</source>
        <translation type="obsolete">MX Vyladění</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="obsolete">Tato aplikace je pouze pro Xfce</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Textový popis</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="30"/>
        <source>MX-Tweak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="56"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="61"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="52"/>
        <location filename="../defaultlook.cpp" line="67"/>
        <location filename="../defaultlook.cpp" line="586"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <location filename="../defaultlook.cpp" line="610"/>
        <location filename="../defaultlook.cpp" line="621"/>
        <source>MX Tweak</source>
        <translation>MX Vyladění</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="147"/>
        <source>Xfce Settings</source>
        <translation>Nastavení Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Upravit vzhled hlavního panelu&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="48"/>
        <location filename="../defaultlook.ui" line="161"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="68"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nastavení chování oken a zástupců&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="82"/>
        <source>Window Manager</source>
        <translation>Správce oken</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="102"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Upravit vzhled pracovní plochy&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="116"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1642"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1670"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1680"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="169"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="189"/>
        <source>Backup current panel configuration</source>
        <translation>Zálohovat aktuální nastavení panelu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="196"/>
        <source>Restore backup panel configuration</source>
        <translation>Obnovit zálohované nastavení panelu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="203"/>
        <source>Restore default panel</source>
        <translation>Obnovit výrobní nastavení</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="216"/>
        <location filename="../defaultlook.ui" line="1311"/>
        <source>Affects 1st panel</source>
        <translation>Ovlyvňuje 1. panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Display panel vertically</source>
        <translation>Zobraz panel vertikálně</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <location filename="../defaultlook.ui" line="1329"/>
        <source>Bottom</source>
        <translation>Dolů</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="248"/>
        <location filename="../defaultlook.ui" line="1339"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="256"/>
        <source>Display panel horizontally</source>
        <translation>Zobraz panel horizontálně</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="276"/>
        <location filename="../defaultlook.ui" line="1334"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="281"/>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="289"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ovlivňuje všechny panely&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="309"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tlačítka okna&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="324"/>
        <location filename="../defaultlook.ui" line="427"/>
        <location filename="../defaultlook.ui" line="618"/>
        <location filename="../defaultlook.ui" line="748"/>
        <location filename="../defaultlook.ui" line="871"/>
        <location filename="../defaultlook.ui" line="878"/>
        <location filename="../defaultlook.ui" line="971"/>
        <location filename="../defaultlook.ui" line="1287"/>
        <location filename="../defaultlook.ui" line="1425"/>
        <location filename="../defaultlook.ui" line="1569"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Theme</source>
        <translation>Motiv</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="361"/>
        <source>Theme Options</source>
        <translation>Nastavení Motivů</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="391"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Opravit některá pole na webových stránkách pří použití tmavého motivu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="394"/>
        <source>Firefox dark theme tweak</source>
        <translation>Potáhnout tmavým motivem i Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="401"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Opravit vstupní pole HexChat-u při použití tmavého motivu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="453"/>
        <source>Undo</source>
        <translation>Vrátit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="460"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="467"/>
        <source>Remove User Theme Set</source>
        <translation>Odebrat uživatelskou sadu motivů</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="478"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Uložit současné nastavení jako uživatelskou sadu motivů</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Compositor</source>
        <translation>Kompozitor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Spustit nástroj pro konfiguraci compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="516"/>
        <source>Compton settings</source>
        <translation>Nastavení Comptonu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="540"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nastavení kompozitoru Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Xfwm Settings</source>
        <translation>Nastavení Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="572"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) kompozitor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="577"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="585"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Editovat compton.conf v textovém editoru</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Edit compton.conf</source>
        <translation>Editovat compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="645"/>
        <source>Transparency and shadow options</source>
        <translation>Volby průhlednosti a stínů</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="652"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Změna režimu VBlank může pomoci zmírnit některé problémy s trháním obrazovky. Další informace naleznete v nápovědě.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="655"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="663"/>
        <source>auto</source>
        <translation>automaticky</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="668"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="673"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="678"/>
        <source>off</source>
        <translation>vypnuto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="888"/>
        <source>Config Options</source>
        <translation>Volby konfigurace</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1447"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Obnovit Lightdm (přihlašovací obrazovku) do výchozího motivu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="896"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Obnovit uživatelské akce pravého tlačítka myši v Thunar do výchozího nastavení</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Použít ovladač intel namísto předvoleného ovladače &quot;modesetting&quot;  (vyžaduje restart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1477"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          POZNÁMKA: existující /etc/X11/xorg.conf.d/20-intel.conf bude zálohován do domovské složky</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1488"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Použít nastavení amdgpu tearfree</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1495"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          POZNÁMKA: existující /etc/X11/xorg.conf.d/20-amd.conf bude zálohován do domovské složky</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1506"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Použít tearfree nastavení ovladače radeon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1513"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          POZNÁMKA: existující /etc/X11/xorg.conf.d/20-radeon.conf bude zálohován do domovské složky</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="707"/>
        <source>Hardware Backlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="714"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="741"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="774"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="781"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="784"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>Software (xrandr) Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="798"/>
        <location filename="../defaultlook.ui" line="812"/>
        <source>TextLabel</source>
        <translation>Textový popis</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="805"/>
        <source>GTK scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="832"/>
        <source>xrandr Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="985"/>
        <source>Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1022"/>
        <location filename="../defaultlook.ui" line="1053"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <location filename="../defaultlook.ui" line="1058"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1063"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1199"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="993"/>
        <location filename="../defaultlook.ui" line="1392"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1000"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1007"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1014"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1035"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1042"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1084"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1091"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1098"/>
        <location filename="../defaultlook.ui" line="1206"/>
        <location filename="../defaultlook.ui" line="1318"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1172"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1182"/>
        <location filename="../defaultlook.ui" line="1280"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1189"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1371"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1378"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1399"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1439"/>
        <source>Other</source>
        <translation>Ostatní</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1536"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1543"/>
        <source>Root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="917"/>
        <source>Show systray (notification area) frame</source>
        <translation>Zobrazit ohraničení systray (oznamovací oblasti)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="924"/>
        <location filename="../defaultlook.ui" line="1385"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Zobrazit v panelu okna všech pracovních ploch</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="903"/>
        <source>Enable single-click on desktop</source>
        <translation>Povolit spouštění jedním kliknutím na ploše</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="938"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Povolit hibernaci v menu odhlášení</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1454"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Povolit uživatelům bez práv roota připojování interních disků</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1461"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="945"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   poznámka: pro hibernaci je potřeba swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="931"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Zakázat zkracování dlouhých názvů souborů na ploše</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="910"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Povolit spouštění jedním kliknutím v Thunar správci souborů</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1529"/>
        <source>Password for administrative tasks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="53"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="585"/>
        <source>About MX Tweak</source>
        <translation>O programu MX Vyladění</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="586"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="587"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplikace pro rychlé změny výchozího vzhledu motivů a vyladění</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="589"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="590"/>
        <location filename="../defaultlook.cpp" line="593"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="591"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="622"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Dokončeno! Firefox může pro zavedení změn vyžadovat restart</translation>
    </message>
    <message>
        <source>This app is Xfce-only</source>
        <translation type="vanished">Tato aplikace je pouze pro Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="806"/>
        <source>Panel settings</source>
        <translation>Nastavení panelu</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="807"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1376"/>
        <source>settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1713"/>
        <source>Choose a theme set</source>
        <translation>Vybrat sadu motivů</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Odebrat uživatelskou sadu motivů</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nová sada motivů</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Zadejte jméno nové sady motivů</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Tlačítka okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vzhled&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Zobrazit popisky tlačítek</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Zobrazit plochá tlačítka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Zobrazit úchytku</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Směr řazení:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Časová známka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Seskupit titulek a časovou známku</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Titulek okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titulek skupiny a titulek okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Žádný, umožnit akci táhnout a pustit</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Chování&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Seskupování oken:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Vždy</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Akce prostředního tlačítka:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Nic</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Zavřít okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimalizovat okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Obnovit minimalizovaná okna na aktuální plochu</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Vykreslit rámeček okna při umístění kurzoru myši nad tlačítko</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Přepínat okna pomocí kolečka myši</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrování&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Zobrazit okna ze všech pracovních ploch a obrazovek</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Zobrazit pouze minimalizovaná okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Zobrazit okna na všech monitorech</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Vyskakovací okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Okna při přesunu</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavení průhlednosti&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Dekorace oken</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Zobrazit stín pod dokovanými okny</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Zobrazit stín pod vyskakovacími okny</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Okna při změně velikosti</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Zobrazit stín pod běžnými okny</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavení funkcí&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Při cyklování zobrazit náhled oken v prostoru ikon</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Zobrazit celoobrazovkové překrytí oken okamžitě</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Neaktivní okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synchronizovat vykreslování s vertikální mezerou</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Nastavení Xfwm kompozitoru</translation>
    </message>
</context>
</TS>
